PageRangeAllocator

Trait PageRangeAllocator 

pub trait PageRangeAllocator {
    // Required methods
    unsafe fn init();
    fn allocate(layout: PageLayout) -> Result<PageRange, AllocError>;
    fn allocate_at(range: PageRange) -> Result<(), AllocError>;
    unsafe fn deallocate(range: PageRange);
}
An allocator that allocates memory in page granularity.

Required Methods

unsafe fn init()

fn allocate(layout: PageLayout) -> Result<PageRange, AllocError>

Attempts to allocate a range of memory in page granularity.

fn allocate_at(range: PageRange) -> Result<(), AllocError>

Attempts to allocate the pages described by range.

unsafe fn deallocate(range: PageRange)

Deallocates the pages described by range.

Safety
  • range must described a range of pages currently allocated via this allocator.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors